==> user-repository-sequelize-0.1.0.tgz: package/src/models/user-uuid.ts <==
/* eslint-disable import/no-cycle */
import { DataTypes, InitOptions, UpdateOptions } from 'sequelize'
import { BaseUserModelAttributes, BaseUserModel } from './baseUser'
import { createSlug } from '../../tests/utils/helper'

export class UUIDUserModel extends BaseUserModel<string> {
	declare name?: string
	declare nameSlug?: string
	declare surname?: string
	declare surnameSlug?: string
	declare phone?: string
	declare phoneSlug?: string
	// foreign keys
	declare createdBy: string
	declare creator: UUIDUserModel
	declare updatedBy: string
	declare editor: UUIDUserModel
	declare deletedBy: string
	declare destructor: UUIDUserModel
}

export const UUIDUserModelAttributes = {
	...BaseUserModelAttributes,
	id: {
		type: DataTypes.UUID,
		allowNull: false,
		primaryKey: true,
		defaultValue: DataTypes.UUIDV4
	},
	name: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	nameSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	surname: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	surnameSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	phone: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	phoneSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	// foreign keys
	createdBy: {
		type: DataTypes.UUID,
		allowNull: false
	},
	updatedBy: {
		type: DataTypes.UUID,
		allowNull: true
	},
	deletedBy: {
		type: DataTypes.UUID,
		allowNull: true
	}
}

/* eslint-disable no-param-reassign */
export const UUIDUserModelOptions: Partial<InitOptions<UUIDUserModel>> = {
	paranoid: true,
	timestamps: true,
	hooks: {
		beforeValidate: (user, options) => {
			if (user.changed('email')) {
				user.emailSlug = createSlug(user.email)
				options.fields?.push('emailSlug')
			}
			if (user.changed('name')) {
				user.nameSlug = createSlug(user.name)
				options.fields?.push('nameSlug')
			}
			if (user.changed('surname')) {
				user.surnameSlug = createSlug(user.surname)
				options.fields?.push('surnameSlug')
			}
			if (user.changed('phone')) {
				user.phoneSlug = createSlug(user.phone)
				options.fields?.push('phoneSlug')
			}
		},
		beforeCreate: (user) => {
			if (user.email) {
				user.emailSlug = createSlug(user.email)
			}
			if (user.name) {
				user.nameSlug = createSlug(user.name)
			}
			if (user.surname) {
				user.surnameSlug = createSlug(user.surname)
			}
			if (user.phone) {
				user.phoneSlug = createSlug(user.phone)
			}
		},
		beforeUpdate: (user) => {
			if (user.changed('name')) {
				user.nameSlug = createSlug(user.name)
			}
			if (user.changed('surname')) {
				user.surnameSlug = createSlug(user.surname)
			}
			if (user.changed('phone')) {
				user.phoneSlug = createSlug(user.phone)
			}
		},
		beforeBulkCreate: (users) => {
			users.forEach((user) => {
				if (user.email) {
					user.emailSlug = createSlug(user.email)
				}
				if (user.name) {
					user.nameSlug = createSlug(user.name)
				}
				if (user.surname) {
					user.surnameSlug = createSlug(user.surname)
				}
				if (user.phone) {
					user.phoneSlug = createSlug(user.phone)
				}
			})
		},
		beforeBulkUpdate: (options: UpdateOptions & { attributes: any }) => {
			options.attributes = {
				...options.attributes
			}

			if (options.attributes.name !== undefined) {
				options.attributes.nameSlug = createSlug(options.attributes.name) || null
				options.fields?.push('nameSlug')
			}
			if (options.attributes.surname !== undefined) {
				options.attributes.surnameSlug = createSlug(options.attributes.surname) || null
				options.fields?.push('surnameSlug')
			}
			if (options.attributes.company !== undefined) {
				options.attributes.companySlug = createSlug(options.attributes.company) || null
				options.fields?.push('companySlug')
			}
			if (options.attributes.companyRole !== undefined) {
				options.attributes.companyRoleSlug = createSlug(options.attributes.companyRole) || null
				options.fields?.push('companyRoleSlug')
			}
			if (options.attributes.phone !== undefined) {
				options.attributes.phoneSlug = createSlug(options.attributes.phone) || null
				options.fields?.push('phoneSlug')
			}
		}
	}
}

function defineUserModelUUID() {
	return UUIDUserModel
}

export default defineUserModelUUID()

==> user-repository-sequelize-0.1.3.tgz: package/src/models/user-uuid.ts <==
/* eslint-disable import/no-cycle */
import { DataTypes, InitOptions, UpdateOptions } from 'sequelize'
import { BaseUserModelAttributes, BaseUserModel } from './baseUser'
import { createSlug } from '../../tests/utils/helper'

export class UUIDUserModel extends BaseUserModel<string> {
	declare name?: string
	declare nameSlug?: string
	declare surname?: string
	declare surnameSlug?: string
	declare phone?: string
	declare phoneSlug?: string
	// foreign keys
	declare createdBy?: string
	declare creator: UUIDUserModel
	declare updatedBy: string
	declare editor: UUIDUserModel
	declare deletedBy: string
	declare destructor: UUIDUserModel
}

export const UUIDUserModelAttributes = {
	...BaseUserModelAttributes,
	id: {
		type: DataTypes.UUID,
		allowNull: false,
		primaryKey: true,
		defaultValue: DataTypes.UUIDV4
	},
	nameSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	surname: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	surnameSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	phone: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	phoneSlug: {
		type: DataTypes.TEXT,
		allowNull: true
	},
	// foreign keys
	createdBy: {
		type: DataTypes.UUID,
		allowNull: true
	},
	updatedBy: {
		type: DataTypes.UUID,
		allowNull: true
	},
	deletedBy: {
		type: DataTypes.UUID,
		allowNull: true
	}
}

/* eslint-disable no-param-reassign */
export const UUIDUserModelOptions: Partial<InitOptions<UUIDUserModel>> = {
	paranoid: true,
	timestamps: true,
	hooks: {
		beforeValidate: (user, options) => {
			if (user.changed('email')) {
				user.emailSlug = createSlug(user.email)
				options.fields?.push('emailSlug')
			}
			if (user.changed('name')) {
				user.nameSlug = createSlug(user.name)
				options.fields?.push('nameSlug')
			}
			if (user.changed('surname')) {
				user.surnameSlug = createSlug(user.surname)
				options.fields?.push('surnameSlug')
			}
			if (user.changed('phone')) {
				user.phoneSlug = createSlug(user.phone)
				options.fields?.push('phoneSlug')
			}
		},
		beforeCreate: (user) => {
			if (user.email) {
				user.emailSlug = createSlug(user.email)
			}
			if (user.name) {
				user.nameSlug = createSlug(user.name)
			}
			if (user.surname) {
				user.surnameSlug = createSlug(user.surname)
			}
			if (user.phone) {
				user.phoneSlug = createSlug(user.phone)
			}
		},
		beforeUpdate: (user) => {
			if (user.changed('name')) {
				user.nameSlug = createSlug(user.name)
			}
			if (user.changed('surname')) {
				user.surnameSlug = createSlug(user.surname)
			}
			if (user.changed('phone')) {
				user.phoneSlug = createSlug(user.phone)
			}
		},
		beforeBulkCreate: (users) => {
			users.forEach((user) => {
				if (user.email) {
					user.emailSlug = createSlug(user.email)
				}
				if (user.name) {
					user.nameSlug = createSlug(user.name)
				}
				if (user.surname) {
					user.surnameSlug = createSlug(user.surname)
				}
				if (user.phone) {
					user.phoneSlug = createSlug(user.phone)
				}
			})
		},
		beforeBulkUpdate: (options: UpdateOptions & { attributes: any }) => {
			options.attributes = {
				...options.attributes
			}

			if (options.attributes.name !== undefined) {
				options.attributes.nameSlug = createSlug(options.attributes.name) || null
				options.fields?.push('nameSlug')
			}
			if (options.attributes.surname !== undefined) {
				options.attributes.surnameSlug = createSlug(options.attributes.surname) || null
				options.fields?.push('surnameSlug')
			}
			if (options.attributes.company !== undefined) {
				options.attributes.companySlug = createSlug(options.attributes.company) || null
				options.fields?.push('companySlug')
			}
			if (options.attributes.companyRole !== undefined) {
				options.attributes.companyRoleSlug = createSlug(options.attributes.companyRole) || null
				options.fields?.push('companyRoleSlug')
			}
			if (options.attributes.phone !== undefined) {
				options.attributes.phoneSlug = createSlug(options.attributes.phone) || null
				options.fields?.push('phoneSlug')
			}
		}
	}
}

function defineUserModelUUID() {
	return UUIDUserModel
}

export default defineUserModelUUID()
